@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# © Copyright EnterpriseDB UK Limited 2011-2023
+# © Copyright EnterpriseDB UK Limited 2011-2025
 #
 # This file is part of Barman.
 #
@@ -230,6 +230,8 @@ class ServerBackupLock(LockFile):
     for the named SERVER.
     """
 
+    LOCK_PATTERN = re.compile(r"\.(?P<server_name>.+)-backup\.lock")
+
     def __init__(self, lock_directory, server_name):
         super(ServerBackupLock, self).__init__(
             os.path.join(lock_directory, ".%s-backup.lock" % server_name),
@@ -245,6 +247,8 @@ class ServerCronLock(LockFile):
     for the named SERVER.
     """
 
+    LOCK_PATTERN = re.compile(r"\.(?P<server_name>.+)-cron\.lock")
+
     def __init__(self, lock_directory, server_name):
         super(ServerCronLock, self).__init__(
             os.path.join(lock_directory, ".%s-cron.lock" % server_name),
@@ -277,6 +281,8 @@ class ServerWalArchiveLock(LockFile):
     the given lock_directory for the named SERVER.
     """
 
+    LOCK_PATTERN = re.compile(r"\.(?P<server_name>.+)-archive-wal\.lock")
+
     def __init__(self, lock_directory, server_name):
         super(ServerWalArchiveLock, self).__init__(
             os.path.join(lock_directory, ".%s-archive-wal.lock" % server_name),
@@ -329,6 +335,10 @@ class ServerBackupSyncLock(LockFile):
     lock_directory for a BACKUP of a SERVER.
     """
 
+    LOCK_PATTERN = re.compile(
+        r"\.(?P<server_name>.+?)-(?P<backup_id>.+?)-sync-backup\.lock"
+    )
+
     def __init__(self, lock_directory, server_name, backup_id):
         super(ServerBackupSyncLock, self).__init__(
             os.path.join(
@@ -347,6 +357,8 @@ class ServerWalSyncLock(LockFile):
     lock_directory for the named SERVER.
     """
 
+    LOCK_PATTERN = re.compile(r"\.(?P<server_name>.+)-sync-wal\.lock")
+
     def __init__(self, lock_directory, server_name):
         super(ServerWalSyncLock, self).__init__(
             os.path.join(lock_directory, ".%s-sync-wal.lock" % server_name),
